@@ -252,8 +252,13 @@ int main(int argc, char *argv[])
   sockun.sun_family = AF_UNIX;
   if (sizeof(sockun.sun_path) < strlen(randsock) + 1)
   {
+#ifdef SIZEOF_IS_LONG_INT
+    fprintf(stderr, "Sockfilename too long: %s, maxlen=%ld\n", randsock,
+	    sizeof(sockun.sun_path));
+#else
     fprintf(stderr, "Sockfilename too long: %s, maxlen=%d\n", randsock,
 	    sizeof(sockun.sun_path));
+#endif /* SIZEOF_IS_LONG_INT */
     exit(EXIT_FAILURE);
   }
 
