@@ -56,7 +56,11 @@ static void child_handler(int received_signal)
     fprintf(stderr, "Caught SIGCHLD\n");
 
   if ((pid = waitpid(-1, &status, WNOHANG)) == -1)
+#ifdef PID_T_IS_LONG_INT
+    fprintf(stderr, "Couldn't wait for child %ld: %s\n", pid, strerror(errno));
+#else
     fprintf(stderr, "Couldn't wait for child %d: %s\n", pid, strerror(errno));
+#endif
   else if ((pid == gatherer_pid) && WIFEXITED(status))
      gatherer_pid = -1;
 
@@ -92,9 +96,11 @@ void main_loop(int service_socket, struct sockaddr_un sockun,
   struct timeval timeout;
 
   gather_fd = -1;
-
   gatherer_entry = 0;
 
+  gatherer_bytes = 0;		/* Initialize to make gcc happy */
+  gather_start = time(NULL);	/* Initialize to make gcc happy */
+
   /*
    * Set up the signal handling. TERM and HUP signals shall lead to clean
    * shutdown of prngd (save the seed and exit).
@@ -348,7 +354,11 @@ void main_loop(int service_socket, struct sockaddr_un sockun,
 	else if (egd_query[i].command == 4)
 	{
 	  egd_query[i].buffer[0] = 12;
+#ifdef PID_T_IS_LONG_INT
+	  sprintf((char *) (egd_query[i].buffer + 1), "%12ld", getpid());
+#else
 	  sprintf((char *) (egd_query[i].buffer + 1), "%12d", getpid());
+#endif
 	  egd_query[i].to_process = 13;
 	  egd_query[i].yet_processed = 0;
 	  egd_query[i].state = wait_write;
